@@ -10,9 +10,9 @@ pytest
 
 tmpdir=$(mktemp -d)
 SCRIPT_DIR=$( cd -- "$( dirname -- "${BASH_SOURCE[0]}" )" &> /dev/null && pwd )
-export PYTHONPATH=$SCRIPT_DIR
+export PYTHONPATH="$PYTHONPATH:$SCRIPT_DIR"
 
-PYTEST_ARGS="--max-examples 200 -v -rxXfE --ci"
+PYTEST_ARGS="--max-examples 200 -v -rxXfE --ci --hypothesis-disable-deadline"
 
 cd $tmpdir
 git clone https://github.com/data-apis/array-api-tests
@@ -26,4 +26,5 @@ mkdir -p $SCRIPT_DIR/.hypothesis
 ln -s $SCRIPT_DIR/.hypothesis .hypothesis
 
 export ARRAY_API_TESTS_MODULE=array_api_compat.cupy
-pytest ${PYTEST_ARGS} --xfails-file $SCRIPT_DIR/cupy-xfails.txt --skips-file $SCRIPT_DIR/cupy-skips.txt "$@"
+export ARRAY_API_TESTS_VERSION=2023.12
+pytest array_api_tests/ ${PYTEST_ARGS} --xfails-file $SCRIPT_DIR/cupy-xfails.txt "$@"
